@@ -96,6 +96,10 @@ def check_signal(key, signal):
     if len(signal.name.strip()) != len(signal.name):
         return False, f"{signal.name}: Device name contains whitespace"
 
+    if int(signal.mux_count) == 0:
+        return False, f"{signal.name}: Mux count is 0. Mux count should be >= 1"
+
+
     return True, ""
 
 
